@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetOperationModules;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -255,7 +255,7 @@ Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, in
 
 =head1 VERSION
 
-This document describes version 0.09 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2016-06-26.
+This document describes version 0.10 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -269,19 +269,23 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
 L<Array::AsObject> 1.02
 
-L<Array::Set> 0.02
+L<Array::Set> 0.05
 
 L<Array::Utils> 0.5
 
-L<List::MoreUtils> 0.413
+L<List::MoreUtils> 0.416
 
-L<List::MoreUtils::PP> 0.413
+L<List::MoreUtils::PP> 0.416
 
 L<Set::Array> 0.30
 
@@ -565,100 +569,101 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m SetOperationModules >>):
 
- +---------------------------------------+---------+-----------+-----------+------------+---------+---------+
- | participant                           | dataset | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +---------------------------------------+---------+-----------+-----------+------------+---------+---------+
- | Array::AsObject::symmetric_difference | num100  |     104.6 | 9.564     |      1     | 9.1e-07 |      20 |
- | Array::AsObject::intersection         | num100  |     213.8 | 4.677     |      2.045 | 4.3e-07 |      20 |
- | Array::AsObject::difference           | num100  |     436   | 2.3       |      4.17  | 2.7e-07 |      20 |
- | Set::Array::intersection              | num100  |     615   | 1.63      |      5.88  | 1.1e-06 |      20 |
- | Array::Set::set_diff                  | num100  |    1400   | 0.713     |     13.4   | 4.3e-07 |      20 |
- | Set::Scalar::intersection             | num100  |    1870   | 0.536     |     17.8   | 2.1e-07 |      20 |
- | Array::Set::set_intersect             | num100  |    1880   | 0.533     |     17.9   | 2.1e-07 |      21 |
- | Array::Set::set_symdiff               | num100  |    1910   | 0.524     |     18.3   | 2.1e-07 |      20 |
- | Set::Scalar::union                    | num100  |    1960   | 0.51      |     18.8   | 2.7e-07 |      20 |
- | Set::Scalar::difference               | num100  |    2050   | 0.487     |     19.6   | 2.4e-07 |      24 |
- | Array::Set::set_union                 | num100  |    2660   | 0.376     |     25.4   | 2.1e-07 |      20 |
- | Set::Scalar::symmetric_difference     | num100  |    2800   | 0.357     |     26.8   | 2.3e-07 |      27 |
- | Array::AsObject::symmetric_difference | num10   |    4690   | 0.213     |     44.9   | 5.3e-08 |      20 |
- | Set::Scalar::intersection             | num10   |   11000   | 0.094     |    100     | 1.1e-07 |      32 |
- | Array::AsObject::intersection         | num10   |   10600   | 0.0942    |    102     | 2.7e-08 |      20 |
- | Set::Scalar::union                    | num10   |   11000   | 0.093     |    100     | 1.1e-07 |      29 |
- | Array::AsObject::union                | num100  |   11000   | 0.091     |    110     | 1.1e-07 |      20 |
- | Set::Scalar::difference               | num10   |   11000   | 0.088     |    110     | 1.1e-07 |      20 |
- | Set::Object::symmetric_difference     | num100  |   11773.7 | 0.0849352 |    112.601 | 9.6e-12 |      20 |
- | Set::Array::difference                | num100  |   12000   | 0.084     |    110     | 1.1e-07 |      31 |
- | Set::Object::intersection             | num100  |   12000   | 0.081     |    120     | 1.1e-07 |      20 |
- | Set::Array::symmetric_difference      | num100  |   13000   | 0.08      |    120     | 1.1e-07 |      20 |
- | Set::Object::union                    | num100  |   14000   | 0.07      |    140     | 2.1e-07 |      20 |
- | Set::Tiny::symmetric_difference       | num100  |   16000   | 0.063     |    150     | 9.5e-08 |      25 |
- | Set::Object::difference               | num100  |   17000   | 0.0589    |    162     | 2.5e-08 |      22 |
- | Array::Set::set_symdiff               | num10   |   17100   | 0.0584    |    164     | 2.4e-08 |      24 |
- | Set::Scalar::symmetric_difference     | num10   |   17200   | 0.058     |    165     | 2.7e-08 |      20 |
- | Set::Tiny::difference                 | num100  |   17000   | 0.058     |    170     | 1.1e-07 |      20 |
- | Set::Tiny::union                      | num100  |   17000   | 0.057     |    170     | 1.1e-07 |      20 |
- | Set::Array::union                     | num100  |   17000   | 0.057     |    170     | 1.1e-07 |      20 |
- | Array::Set::set_intersect             | num10   |   18000   | 0.056     |    170     | 1.1e-07 |      20 |
- | Set::Tiny::intersection               | num100  |   18000   | 0.054     |    180     | 1.1e-07 |      20 |
- | Array::AsObject::difference           | num10   |   21800   | 0.0459    |    208     | 1.1e-08 |      28 |
- | Array::Set::set_union                 | num10   |   24144.1 | 0.0414179 |    230.91  | 1.1e-11 |      20 |
- | List::MoreUtils::PP::singleton        | num100  |   25300   | 0.0395    |    242     | 1.1e-08 |      30 |
- | Array::Utils::array_diff              | num100  |   25806.5 | 0.0387499 |    246.808 |   1e-11 |      21 |
- | Array::Set::set_diff                  | num10   |   28000   | 0.036     |    270     | 3.8e-08 |      22 |
- | Array::Utils::array_minus             | num100  |   29000   | 0.035     |    280     | 4.2e-08 |      33 |
- | Array::Utils::intersect               | num100  |   29300   | 0.0341    |    280     | 3.1e-08 |      33 |
- | List::MoreUtils::PP::uniq             | num100  |   33300   | 0.03      |    319     | 9.9e-09 |      36 |
- | Set::Array::intersection              | num10   |   35471.5 | 0.0281917 |    339.242 |   1e-11 |      20 |
- | List::MoreUtils::XS::singleton        | num100  |   44200   | 0.0226    |    423     | 5.8e-09 |      26 |
- | List::MoreUtils::XS::uniq             | num100  |   56700   | 0.0176    |    542     | 5.8e-09 |      26 |
- | Set::Array::difference                | num10   |   61800   | 0.0162    |    591     | 6.7e-09 |      20 |
- | Set::Array::symmetric_difference      | num10   |   68300   | 0.0146    |    653     | 6.7e-09 |      20 |
- | Set::Object::symmetric_difference     | num10   |   70100   | 0.0143    |    670     | 6.4e-09 |      22 |
- | Array::AsObject::union                | num10   |   72000   | 0.0139    |    689     | 6.1e-09 |      24 |
- | Set::Array::union                     | num10   |   86820.4 | 0.011518  |    830.334 | 9.8e-12 |      22 |
- | Set::Object::intersection             | num10   |  100000   | 0.00996   |    960     | 3.3e-09 |      21 |
- | Set::Object::union                    | num10   |  114000   | 0.00874   |   1090     | 3.3e-09 |      20 |
- | Set::Object::difference               | num10   |  126000   | 0.00797   |   1200     | 2.7e-09 |      30 |
- | Set::Tiny::symmetric_difference       | num10   |  128000   | 0.00782   |   1220     | 7.8e-09 |      33 |
- | Set::Tiny::difference                 | num10   |  138000   | 0.00724   |   1320     | 3.3e-09 |      20 |
- | Set::Tiny::union                      | num10   |  140000   | 0.0069    |   1400     | 7.6e-09 |      35 |
- | Set::Tiny::intersection               | num10   |  150000   | 0.0065    |   1500     | 9.8e-09 |      21 |
- | Array::Utils::array_diff              | num10   |  209380   | 0.0047759 |   2002.5   | 9.5e-12 |      20 |
- | List::MoreUtils::PP::singleton        | num10   |  220000   | 0.0045    |   2100     | 5.5e-09 |      29 |
- | Array::Utils::unique                  | num100  |  235000   | 0.00426   |   2250     | 1.7e-09 |      20 |
- | Array::Utils::array_minus             | num10   |  254190   | 0.003934  |   2431.1   | 9.8e-12 |      20 |
- | Array::Utils::intersect               | num10   |  258200   | 0.003872  |   2470     | 4.7e-11 |      20 |
- | List::MoreUtils::PP::uniq             | num10   |  290000   | 0.0034    |   2800     |   4e-09 |      31 |
- | List::MoreUtils::XS::singleton        | num10   |  400000   | 0.0025    |   3900     | 3.3e-09 |      20 |
- | List::MoreUtils::XS::uniq             | num10   |  501120   | 0.0019955 |   4792.6   | 9.3e-12 |      20 |
- | Array::Utils::unique                  | num10   |  750000   | 0.0013    |   7100     | 1.7e-09 |      20 |
- +---------------------------------------+---------+-----------+-----------+------------+---------+---------+
+ #table1#
+ +---------------------------------------+---------+-----------+------------+------------+---------+---------+
+ | participant                           | dataset | rate (/s) | time (ms)  | vs_slowest |  errors | samples |
+ +---------------------------------------+---------+-----------+------------+------------+---------+---------+
+ | Array::AsObject::symmetric_difference | num100  |      79   | 13         |     1      | 9.1e-05 |      20 |
+ | Array::AsObject::intersection         | num100  |     160   |  6.2       |     2      | 6.1e-05 |      20 |
+ | Array::AsObject::difference           | num100  |     330   |  3.1       |     4.1    | 4.3e-06 |      22 |
+ | Set::Array::intersection              | num100  |     440   |  2.3       |     5.6    |   7e-06 |      36 |
+ | Set::Scalar::intersection             | num100  |    1410   |  0.711     |    17.9    | 4.3e-07 |      20 |
+ | Set::Scalar::union                    | num100  |    1500   |  0.68      |    19      | 9.1e-07 |      20 |
+ | Set::Scalar::difference               | num100  |    1550   |  0.644     |    19.7    | 2.1e-07 |      20 |
+ | Set::Scalar::symmetric_difference     | num100  |    2120   |  0.472     |    26.9    | 4.3e-07 |      20 |
+ | Array::AsObject::symmetric_difference | num10   |    4000   |  0.3       |    50      | 2.9e-06 |      23 |
+ | Set::Object::symmetric_difference     | num100  |    7000   |  0.14      |    89      | 2.3e-07 |      28 |
+ | Array::AsObject::intersection         | num10   |    7666   |  0.130446  |    97.3485 | 3.4e-11 |      22 |
+ | Set::Scalar::intersection             | num10   |    7700   |  0.13      |    98      | 2.2e-07 |      29 |
+ | Array::AsObject::union                | num100  |    7900   |  0.13      |   100      | 2.3e-07 |      28 |
+ | Set::Scalar::union                    | num10   |    8000   |  0.12      |   100      | 1.9e-07 |      25 |
+ | Set::Object::intersection             | num100  |    8100   |  0.12      |   100      | 1.8e-07 |      28 |
+ | Set::Scalar::difference               | num10   |    8200   |  0.12      |   100      | 2.3e-07 |      27 |
+ | Set::Array::symmetric_difference      | num100  |    9000   |  0.11      |   110      | 4.3e-07 |      20 |
+ | Set::Array::difference                | num100  |   10000   |  0.097     |   130      | 1.3e-07 |      20 |
+ | Set::Object::union                    | num100  |   10000   |  0.095     |   130      | 1.1e-07 |      20 |
+ | Set::Tiny::symmetric_difference       | num100  |   12000   |  0.086     |   150      |   1e-07 |      22 |
+ | Set::Object::difference               | num100  |   12000   |  0.082     |   150      | 1.2e-07 |      24 |
+ | Set::Array::union                     | num100  |   12000   |  0.08      |   160      | 9.7e-08 |      24 |
+ | Set::Tiny::difference                 | num100  |   13000   |  0.079     |   160      | 1.1e-07 |      20 |
+ | Set::Tiny::union                      | num100  |   13000   |  0.079     |   160      | 1.9e-07 |      31 |
+ | Set::Scalar::symmetric_difference     | num10   |   13000   |  0.0769    |   165      | 2.7e-08 |      20 |
+ | Set::Tiny::intersection               | num100  |   15000   |  0.068     |   190      |   8e-08 |      20 |
+ | Array::Set::set_symdiff               | num100  |   14800   |  0.0676    |   188      | 2.7e-08 |      20 |
+ | Array::Set::set_intersect             | num100  |   15551.5 |  0.0643027 |   197.484  | 9.8e-12 |      22 |
+ | Array::Set::set_union                 | num100  |   17300   |  0.0578    |   220      | 2.7e-08 |      20 |
+ | Array::AsObject::difference           | num10   |   18000   |  0.0555    |   229      | 2.7e-08 |      20 |
+ | List::MoreUtils::PP::singleton        | num100  |   18000   |  0.055     |   230      | 1.1e-07 |      20 |
+ | Array::Utils::array_diff              | num100  |   19000   |  0.0526    |   241      | 2.5e-08 |      23 |
+ | Array::Set::set_diff                  | num100  |   21000   |  0.047     |   270      | 6.4e-08 |      22 |
+ | Array::Utils::array_minus             | num100  |   21800   |  0.0459    |   276      | 1.2e-08 |      24 |
+ | Array::Utils::intersect               | num100  |   21884.2 |  0.0456952 |   277.901  | 3.4e-11 |      20 |
+ | List::MoreUtils::PP::uniq             | num100  |   24000   |  0.042     |   300      | 5.3e-08 |      20 |
+ | Set::Array::intersection              | num10   |   25605   |  0.039055  |   325.15   | 1.8e-10 |      20 |
+ | List::MoreUtils::XS::singleton        | num100  |   30088.2 |  0.0332356 |   382.083  |   0     |      20 |
+ | List::MoreUtils::XS::uniq             | num100  |   44000   |  0.023     |   560      | 2.7e-08 |      20 |
+ | Set::Object::symmetric_difference     | num10   |   45000   |  0.022     |   570      | 2.7e-08 |      20 |
+ | Set::Array::difference                | num10   |   47000   |  0.021     |   590      | 5.2e-08 |      27 |
+ | Set::Array::symmetric_difference      | num10   |   49000   |  0.02      |   630      | 2.7e-08 |      30 |
+ | Array::AsObject::union                | num10   |   53498   |  0.018692  |   679.36   | 4.8e-11 |      29 |
+ | Set::Object::intersection             | num10   |   66400   |  0.0151    |   843      | 6.7e-09 |      20 |
+ | Set::Array::union                     | num10   |   66600   |  0.015     |   846      | 6.7e-09 |      20 |
+ | Set::Object::union                    | num10   |   80000   |  0.013     |  1000      | 1.3e-08 |      20 |
+ | Set::Object::difference               | num10   |   92700   |  0.0108    |  1180      | 3.3e-09 |      20 |
+ | Set::Tiny::symmetric_difference       | num10   |   97000   |  0.01      |  1200      | 1.3e-08 |      21 |
+ | Set::Tiny::difference                 | num10   |  110000   |  0.0091    |  1400      | 2.6e-08 |      26 |
+ | Set::Tiny::union                      | num10   |  110000   |  0.0091    |  1400      |   1e-08 |      20 |
+ | Array::Set::set_symdiff               | num10   |  127000   |  0.0079    |  1610      | 2.8e-09 |      29 |
+ | Set::Tiny::intersection               | num10   |  130000   |  0.00767   |  1660      | 3.2e-09 |      22 |
+ | Array::Set::set_intersect             | num10   |  133000   |  0.0075    |  1690      | 3.3e-09 |      20 |
+ | Array::Set::set_union                 | num10   |  140000   |  0.0069    |  1800      | 8.9e-09 |      25 |
+ | Array::Utils::array_diff              | num10   |  156400   |  0.0063939 |  1986.1    | 3.4e-11 |      36 |
+ | List::MoreUtils::PP::singleton        | num10   |  170000   |  0.0061    |  2100      | 6.7e-09 |      20 |
+ | Array::Set::set_diff                  | num10   |  167000   |  0.00598   |  2120      |   5e-09 |      20 |
+ | Array::Utils::unique                  | num100  |  170000   |  0.0057    |  2200      | 6.7e-09 |      20 |
+ | Array::Utils::intersect               | num10   |  192000   |  0.00521   |  2440      | 1.7e-09 |      20 |
+ | Array::Utils::array_minus             | num10   |  192000   |  0.0052    |  2440      | 1.3e-09 |      32 |
+ | List::MoreUtils::PP::uniq             | num10   |  214000   |  0.00468   |  2710      | 1.7e-09 |      20 |
+ | List::MoreUtils::XS::singleton        | num10   |  303000   |  0.0033    |  3840      | 1.6e-09 |      22 |
+ | List::MoreUtils::XS::uniq             | num10   |  380000   |  0.0027    |  4800      | 6.7e-09 |      20 |
+ | Array::Utils::unique                  | num10   |  585600   |  0.001708  |  7436      | 9.5e-11 |      32 |
+ +---------------------------------------+---------+-----------+------------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m SetOperationModules --module-startup >>):
 
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Set::Array          |      15   |                   12.5 |        1   | 2.1e-05 |      20 |
- | Array::AsObject     |      14   |                   11.5 |        1   | 5.4e-05 |      20 |
- | Set::Object         |      12   |                    9.5 |        1.2 | 2.6e-05 |      21 |
- | Set::Scalar         |      11   |                    8.5 |        1.3 | 3.1e-05 |      20 |
- | List::MoreUtils     |       9.9 |                    7.4 |        1.5 | 3.6e-05 |      21 |
- | Array::Set          |       8.6 |                    6.1 |        1.7 | 1.3e-05 |      20 |
- | List::MoreUtils::PP |       5.5 |                    3   |        2.7 | 1.1e-05 |      20 |
- | Set::Tiny           |       3.8 |                    1.3 |        3.9 | 8.7e-06 |      20 |
- | Array::Utils        |       3.5 |                    1   |        4.2 |   2e-05 |      20 |
- | perl -e1 (baseline) |       2.5 |                    0   |        5.8 |   7e-06 |      20 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Set::Array          | 3.1                          | 6.4                | 22             |      21   |                   15   |        1   | 5.7e-05 |      21 |
+ | Array::AsObject     | 2.2                          | 5.6                | 19             |      21   |                   15   |        1   | 8.1e-05 |      20 |
+ | Set::Object         | 1                            | 4.4                | 16             |      17   |                   11   |        1.2 | 9.2e-05 |      20 |
+ | Set::Scalar         | 1.2                          | 4.5                | 16             |      16   |                   10   |        1.3 | 5.4e-05 |      20 |
+ | List::MoreUtils     | 1.1                          | 4.5                | 16             |      13   |                    7   |        1.6 | 9.2e-05 |      20 |
+ | List::MoreUtils::PP | 1.6                          | 5                  | 19             |       9.9 |                    3.9 |        2.1 | 6.1e-05 |      20 |
+ | Array::Set          | 2.7                          | 6                  | 24             |       9   |                    3   |        2.3 | 4.6e-05 |      20 |
+ | Set::Tiny           | 0.93                         | 4.3                | 16             |       7.1 |                    1.1 |        2.9 | 2.3e-05 |      21 |
+ | Array::Utils        | 1.9                          | 5.4                | 19             |       7   |                    1   |        3   | 4.9e-05 |      21 |
+ | perl -e1 (baseline) | 0.9                          | 4                  | 20             |       6   |                    0   |        4   | 8.5e-05 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -689,7 +694,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
